/****************************************************************************
*  This file is part of the lpc1000 port for the TNKernel RTOS
*
*  Copyright (c) 2009 by Michael Fischer. All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
*****************************************************************************
*  History:
*
*  26.09.2009  mifi   First Version
****************************************************************************/
#if !defined(__TN_PORT_LPC1000_H__) && defined(TN_ARCH_CM3) && defined(TN_PORT_LPC1000)
#define __TN_PORT_LPC1000_H__

/***************************************************************************/
/*  DEFINE: All Structures and Commn Constants                             */
/***************************************************************************/

/*
 * Define the irq id and prio type, this makes it easier
 * if it must changed e.g. from unsigned char to unsigned short.
 */
typedef unsigned char         TN_IRQ_ID;
typedef unsigned char         TN_IRQ_PRIO;

/*
 * The lpc1000 suports 35 irq's with 32 priority levels.
 */
#define TN_MAX_IRQ_ID         35
#define TN_MAX_IRQ_PRIO       32

#define WDT_IRQHandler_ID     0
#define TIMER0_IRQHandler_ID  1
#define TIMER1_IRQHandler_ID  2
#define TIMER2_IRQHandler_ID  3
#define TIMER3_IRQHandler_ID  4
#define UART0_IRQHandler_ID   5
#define UART1_IRQHandler_ID   6
#define UART2_IRQHandler_ID   7
#define UART3_IRQHandler_ID   8
#define PWM1_IRQHandler_ID    9
#define I2C0_IRQHandler_ID    10
#define I2C1_IRQHandler_ID    11
#define I2C2_IRQHandler_ID    12
#define SPI_IRQHandler_ID     13
#define SSP0_IRQHandler_ID    14
#define SSP1_IRQHandler_ID    15
#define PLL0_IRQHandler_ID    16
#define RTC_IRQHandler_ID     17
#define EINT0_IRQHandler_ID   18
#define EINT1_IRQHandler_ID   19
#define EINT2_IRQHandler_ID   20
#define EINT3_IRQHandler_ID   21
#define ADC_IRQHandler_ID     22
#define BOD_IRQHandler_ID     23
#define USB_IRQHandler_ID     24
#define CAN_IRQHandler_ID     25
#define GPDMA_IRQHandler_ID   26
#define I2S_IRQHandler_ID     27
#define ENET_IRQHandler_ID    28
#define RIT_IRQHandler_ID     29
#define MCPWM_IRQHandler_ID   30
#define QEI_IRQHandler_ID     31
#define PLL1_IRQHandler_ID    32
#define USBACT_IRQHandler_ID  33
#define CANACT_IRQHandler_ID  34

/***************************************************************************/
/*                 P R O T O T Y P E S                                     */
/***************************************************************************/
void tn_irq_init (void);
int tn_irq_install (TN_IRQ_ID   id,
                    TN_IRQ_PRIO prio,
                    void (*irq_func)(void));

#endif /* !__TN_PORT_LPC1000_H__ && TN_ARCH_CM3 && TN_PORT_LPC1000 */
/*** EOF ***/
