/****************************************************************************
*  This file is part of the stm32 port for the TNKernel RTOS
*
*  Copyright (c) 2009 by Michael Fischer. All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
*****************************************************************************
*  History:
*
*  26.09.2009  mifi   First Version
****************************************************************************/
#if !defined(__TN_PORT_STM32_H__) && defined(TN_ARCH_CM3) && defined(TN_PORT_STM32)
#define __TN_PORT_STM32_H__

/***************************************************************************/
/*  DEFINE: All Structures and Commn Constants                             */
/***************************************************************************/

/*
 * Define the irq id and prio type, this makes it easier
 * if it must changed e.g. from unsigned char to unsigned short.
 */
typedef unsigned char      TN_IRQ_ID;
typedef unsigned char      TN_IRQ_PRIO;

/*
 * The stm32 suports 60 irq's with 16 priority levels.
 */
#define TN_MAX_IRQ_ID      60
#define TN_MAX_IRQ_PRIO    16

#define WWDG_IRQHandler_ID             0
#define PVD_IRQHandler_ID              1
#define TAMPER_IRQHandler_ID           2
#define RTC_IRQHandler_ID              3
#define FLASH_IRQHandler_ID            4
#define RCC_IRQHandler_ID              5
#define EXTI0_IRQHandler_ID            6
#define EXTI1_IRQHandler_ID            7
#define EXTI2_IRQHandler_ID            8
#define EXTI3_IRQHandler_ID            9
#define EXTI4_IRQHandler_ID            10
#define DMA1_Channel1_IRQHandler_ID    11
#define DMA1_Channel2_IRQHandler_ID    12
#define DMA1_Channel3_IRQHandler_ID    13
#define DMA1_Channel4_IRQHandler_ID    14
#define DMA1_Channel5_IRQHandler_ID    15
#define DMA1_Channel6_IRQHandler_ID    16
#define DMA1_Channel7_IRQHandler_ID    17
#define ADC1_2_IRQHandler_ID           18
#define USB_HP_CAN1_TX_IRQHandler_ID   19
#define USB_LP_CAN1_RX0_IRQHandler_ID  20
#define CAN1_RX1_IRQHandler_ID         21
#define CAN1_SCE_IRQHandler_ID         22
#define EXTI9_5_IRQHandler_ID          23
#define TIM1_BRK_IRQHandler_ID         24
#define TIM1_UP_IRQHandler_ID          25
#define TIM1_TRG_COM_IRQHandler_ID     26
#define TIM1_CC_IRQHandler_ID          27
#define TIM2_IRQHandler_ID             28
#define TIM3_IRQHandler_ID             29
#define TIM4_IRQHandler_ID             30
#define I2C1_EV_IRQHandler_ID          31
#define I2C1_ER_IRQHandler_ID          32
#define I2C2_EV_IRQHandler_ID          33
#define I2C2_ER_IRQHandler_ID          34
#define SPI1_IRQHandler_ID             35
#define SPI2_IRQHandler_ID             36
#define USART1_IRQHandler_ID           37
#define USART2_IRQHandler_ID           38
#define USART3_IRQHandler_ID           39
#define EXTI15_10_IRQHandler_ID        40
#define RTCAlarm_IRQHandler_ID         41
#define USBWakeUp_IRQHandler_ID        42
#define TIM8_BRK_IRQHandler_ID         43
#define TIM8_UP_IRQHandler_ID          44
#define TIM8_TRG_COM_IRQHandler_ID     45
#define TIM8_CC_IRQHandler_ID          46
#define ADC3_IRQHandler_ID             47
#define FSMC_IRQHandler_ID             48
#define SDIO_IRQHandler_ID             49
#define TIM5_IRQHandler_ID             50
#define SPI3_IRQHandler_ID             51
#define UART4_IRQHandler_ID            52
#define UART5_IRQHandler_ID            53
#define TIM6_IRQHandler_ID             54
#define TIM7_IRQHandler_ID             55
#define DMA2_Channel1_IRQHandler_ID    56
#define DMA2_Channel2_IRQHandler_ID    57
#define DMA2_Channel3_IRQHandler_ID    58
#define DMA2_Channel4_5_IRQHandler_ID  59

/***************************************************************************/
/*                 P R O T O T Y P E S                                     */
/***************************************************************************/
void tn_irq_init (void);
int tn_irq_install (TN_IRQ_ID   id,
                    TN_IRQ_PRIO prio,
                    void (*irq_func)(void));

#endif /* !__TN_PORT_STM32_H__ && TN_ARCH_CM3 && TN_PORT_STM32 */
/*** EOF ***/
